////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
// File Name: TVP7002_THS8200_VGA_to_YCbCr_444_DS_to_VGA.cmd
// Release Date: 04-22-2013
// For use with the TVP7002+THS8200 EVM Kit

// Description:
//  This command file programs the TVP7002 and THS8200 register settings for the following graphics formats:
//   - All VESA DMT graphics formats up to 162MHz

// The following Include files provide register settings that are the same for all graphics formats.
//  - TVP7002_default_settings.inc
//  - THS8200_default_settings.inc
//  - TVP7002_VGA_to_YCbCr_444_DS_common.inc
//  - THS8200_YCbCr_444_DS_to_VGA_common.inc

// The input MUX is configured for PC graphics inputs on the VGA connector input.
// Optimum Phase Sel setting will vary depending on the graphics source used.
// TVP7002 and THS8200 discrete sync outputs are set up to match those specified in the VESA DMT graphics standard.
// The TVP7002 is set up to use a 27MHz external REFCLK.

// Acronyms:
// RB   Reduced Blanking
// HS   Horizontal Sync
// VS   Vertical Sync
// DS   Discrete Sync
// ES   Embedded Sync
// SOY  Sync on Y
// DMT  Display Monitor Timing
// VGA  Video Graphics Array
////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"Data Enable Output on Pin 22 of TVP7002"

WR_REG,TVP7000,0x01,0x17,0x10 // MISC Control 2, DE out, outputs enabled

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"Field ID Output on Pin 22 of TVP7002 (default)"

WR_REG,TVP7000,0x01,0x17,0x00 // MISC Control 2, FID out, outputs enabled 

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"*** 5-wire VGA to 30-bit YCbCr 4:4:4 DS to 5-wire VGA settings for TVP7002 + THS8200 ***"

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 04h, 640x480 @ 60Hz, 31.469kHz, 25.175MHz, HS/VS -/-, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x32 // H-PLL Feedback Divider MSBs - 800 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x20 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x60 // HSYNC Output Width - 96 pixels
WR_REG,TVP7000,0x01,0x0E,0x00 // Sync Control 1 - HSout- VSout-
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0xA9 // AVID Start Pixel LSB - 169 (144 + 25) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x0D // AVID Stop Pixel LSB - 13 (169 + 640 + 4) - 800 pixels
WR_REG,TVP7000,0x01,0x43,0x00 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x0A // VBLK F0 Start Line Offset - 10 lines
WR_REG,TVP7000,0x01,0x45,0x0A // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x11 // chip_ctl - low DLL freq range
//timing setup
WR_REG,THS8200,0x01,0x25,0x60 // dtg1_spec_a  96
WR_REG,THS8200,0x01,0x26,0x0E // dtg1_spec_b  Hfp - 2 (16 - 2)
WR_REG,THS8200,0x01,0x28,0x90 // dtg1_spec_d  144
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x0E // dtg1_spec_k_lsb  16 - 2
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x03 // dtg1_total_pixel_msb  800 pixels
WR_REG,THS8200,0x01,0x35,0x20 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x22 // dtg1_frame_field_msb  525 lines
WR_REG,THS8200,0x01,0x3A,0x0D // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x0D // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to 526 (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x02 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x0E // dtg2_bp2_lsb

//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x60 // dtg2_hlength_lsb  HS = 96 pixels
WR_REG,THS8200,0x01,0x73,0x03 // dtg2_vlength_lsb  VS = 2 + 1

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x00 // dtg2_cntl, YPbPr mode, discrete syncs, -HS -VS 

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 09h, 800x600 @ 60Hz, 37.879kHz, 40.000MHz, HS/VS +/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x42 // H-PLL Feedback Divider MSBs - 1056 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs 
WR_REG,TVP7000,0x01,0x03,0x58 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x80 // HSYNC Output Width - 128 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0xF1 // AVID Start Pixel LSB - 241 (25 + 216) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x15 // AVID Stop Pixel LSB - 1045 (241 + 800 + 4) pixels
WR_REG,TVP7000,0x01,0x43,0x04 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1C // VBLK F0 Duration - 28 lines
WR_REG,TVP7000,0x01,0x47,0x1C // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl - high DLL freq range
//timing setup
WR_REG,THS8200,0x01,0x25,0x80 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x26 // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0xD8 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x26 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x04 // dtg1_total_pixel_msb  1056 pixels
WR_REG,THS8200,0x01,0x35,0x20 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x22 // dtg1_frame_field_msb   628 lines
WR_REG,THS8200,0x01,0x3A,0x74 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x74 // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to 629 (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x02 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x75 // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x80 // dtg2_hlength_lsb  HS = 128 pixels
WR_REG,THS8200,0x01,0x73,0x05 // dtg2_vlength_lsb  VS = 4 + 1

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x1B // dtg2_cntl, YPbPr mode, discrete syncs, +HS +VS

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 0Eh, 848x480 @ 60Hz, 31.020kHz, 33.750MHz, HS/VS +/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x44 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x18 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x70 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0xF8 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x0C // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x00 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x06 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x06 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x25 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x25 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x11 // chip_ctl
//timing setup
WR_REG,THS8200,0x01,0x25,0x70 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x0E // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0xE0 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x0E // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x04 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x40 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x22 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x05 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x05 // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x02 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x06 // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x70 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x73,0x09 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x1B // dtg2_cntl, YPbPr mode, discrete syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 10h, 1024x768 @ 60Hz, 48.363kHz, 65.000MHz, HS/VS -/-, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x54 // H-PLL Feedback Divider MSBs - 1344 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x58 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x88 // HSYNC Output Width - 136 pixels
WR_REG,TVP7000,0x01,0x0E,0x00 // Sync Control 1 - HSout- VSout-
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x41 // AVID Start Pixel LSB - 321 (25 + 296) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x05 // AVID Stop Pixel LSB - 5 (321 + 1024 + 4) - 1344 pixels
WR_REG,TVP7000,0x01,0x43,0x00 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x26 // VBLK F0 Duration - 38 lines
WR_REG,TVP7000,0x01,0x47,0x26 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl - high DLL freq range
//timing setup
WR_REG,THS8200,0x01,0x25,0x88 // dtg1_spec_a  136
WR_REG,THS8200,0x01,0x26,0x16 // dtg1_spec_b  24 - 2
WR_REG,THS8200,0x01,0x28,0x28 // dtg1_spec_d  296
WR_REG,THS8200,0x01,0x2B,0x80 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x16 // dtg1_spec_k_lsb  24 - 2
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x05 // dtg1_total_pixel_msb  1344 pixels
WR_REG,THS8200,0x01,0x35,0x40 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x33 // dtg1_frame_field_msb   806 lines
WR_REG,THS8200,0x01,0x3A,0x26 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x26 // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to 807 (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x03 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x27 // dtg2_bp2_lsb

//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x88 // dtg2_hlength_lsb  136 pixels
WR_REG,THS8200,0x01,0x73,0x07 // dtg2_vlength_lsb  6 + 1

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x00 // dtg2_cntl, YPbPr mode, discrete syncs, -HS -VS

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 16h, 1280x768 @ 60Hz, 47.396kHz, 68.250MHz, HS/VS +/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x5A // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x50 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x20 // Sync Control 1
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x89 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x8D // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x05 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x16 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x16 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl
//timing setup
WR_REG,THS8200,0x01,0x25,0x20 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x2E // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0x70 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x2E // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x05 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0xA0 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x33 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x16 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x16 // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x03 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x17 // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x20 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x73,0x08 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x09 // dtg2_cntl, YPbPr mode, discrete syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 17h, 1280x768 @ 60Hz, 47.776kHz, 79.500MHz, HS/VS -/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x68 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x80 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x59 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x5D // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl
//timing setup
WR_REG,THS8200,0x01,0x25,0x80 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x3E // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0x40 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x80 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x3E // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x06 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x80 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x33 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x1E // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x1E // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x03 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x1F // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x80 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x73,0x08 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x12 // dtg2_cntl, YPbPr mode, discrete syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 1Bh, 1280x800 @ 60Hz, 49.306kHz, 71.000MHz, HS/VS +/-, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x5A // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x20 // Sync Control 1
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x89 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x8D // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x05 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x17 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x17 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl
//timing setup
WR_REG,THS8200,0x01,0x25,0x20 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x2E // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0x70 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x2E // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x05 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0xA0 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x33 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x37 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x37 // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x03 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x38 // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x20 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x73,0x07 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x09 // dtg2_cntl, YPbPr mode, discrete syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 1Ch, 1280x800 @ 60Hz, 49.702kHz, 83.500MHz, HS/VS -/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x69 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x80 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x61 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x65 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1F // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x1F // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl
//timing setup
WR_REG,THS8200,0x01,0x25,0x80 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x46 // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0x48 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x80 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x46 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x06 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x90 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x33 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x3F // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x3F // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x03 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x40 // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x80 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x73,0x07 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x12 // dtg2_cntl, YPbPr mode, discrete syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 20h, 1280x960 @ 60Hz, 60.000kHz, 108.000MHz, HS/VS +/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x70 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x70 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0xC1 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0xC5 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x28 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x28 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl
//timing setup
WR_REG,THS8200,0x01,0x25,0x70 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x5E // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0xA8 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x80 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x5E // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x07 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x08 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x33 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0xE8 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0xE8 // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x03 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0xE9 // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x70 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x73,0x04 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x1B // dtg2_cntl, YPbPr mode, discrete syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 23h, 1280x1024 @ 60Hz, 63.981kHz, 108.000MHz, HS/VS +/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x69 // H-PLL Feedback Divider MSBs - 1688 pixels
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs 
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x70 // HSYNC Output Width - 112 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x81 // AVID Start Pixel LSB - 25 + HS + Hbp = 25 + 112 + 248 = 385 pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x85 // AVID Stop Pixel LSB - AVID Start + Act Pix + 4 = 385 + 1280 + 4 = 1669 pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2A // VBLK F0 Duration - 42 lines
WR_REG,TVP7000,0x01,0x47,0x2A // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl - high DLL freq range
//timing setup
WR_REG,THS8200,0x01,0x25,0x70 // dtg1_spec_a  112
WR_REG,THS8200,0x01,0x26,0x2E // dtg1_spec_b  48 - 2
WR_REG,THS8200,0x01,0x28,0x68 // dtg1_spec_d  360
WR_REG,THS8200,0x01,0x2B,0x80 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x2E // dtg1_spec_k_lsb  48 - 2
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x06 // dtg1_total_pixel_msb  1688 pixels
WR_REG,THS8200,0x01,0x35,0x98 // dtg1_total_pixel_lsb 
WR_REG,THS8200,0x01,0x39,0x44 // dtg1_frame_field_msb  1066 lines
WR_REG,THS8200,0x01,0x3A,0x2A // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x2A // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to 1067 (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x04 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x2B // dtg2_bp2_lsb

//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x70 // dtg2_hlength_lsb  112 pixels
WR_REG,THS8200,0x01,0x73,0x04 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x1B // dtg2_cntl, YPbPr mode, discrete syncs, +HS +VS

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 27h, 1360x768 @ 60Hz, 47.712kHz, 85.500MHz, HS/VS +/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x70 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x70 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x89 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0xDD // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1B // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x1B // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl
//timing setup
WR_REG,THS8200,0x01,0x25,0x70 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x3E // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0x70 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x80 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x3E // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x07 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x00 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x33 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x1B // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x1B // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x03 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x1C // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x70 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x73,0x07 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x1B // dtg2_cntl, YPbPr mode, discrete syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 29h, 1440x1050 @ 60Hz, 64.744kHz, 101.000MHz, HS/VS +/-, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x61 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x20 // Sync Control 1
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x89 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x05 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl
//timing setup
WR_REG,THS8200,0x01,0x25,0x20 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x2E // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0x70 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x2E // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x06 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x18 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x44 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x38 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x38 // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x04 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x39 // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x20 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x73,0x05 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x09 // dtg2_cntl, YPbPr mode, discrete syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 2Ah, 1440x1050 @ 60Hz, 65.317kHz, 121.7500MHz, HS/VS -/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x74 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x90 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x91 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x0D // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x07 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x27 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x27 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl
//timing setup
WR_REG,THS8200,0x01,0x25,0x90 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x56 // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0x78 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x80 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x56 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x07 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x48 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x44 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x41 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x41 // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x04 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x42 // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x90 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x73,0x05 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x12 // dtg2_cntl, YPbPr mode, discrete syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 2Eh, 1440x900 @ 60Hz, 55.469kHz, 88.750MHz, HS/VS +/-, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x64 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x20 // Sync Control 1
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x89 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x2D // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1A // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x1A // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl
//timing setup
WR_REG,THS8200,0x01,0x25,0x20 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x2E // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0x70 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x2E // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x06 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x40 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x33 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x9E // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x9E // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x03 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x9F // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x20 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x73,0x07 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x09 // dtg2_cntl, YPbPr mode, discrete syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 2Fh, 1440x900 @ 60Hz, 55.935kHz, 106.500MHz, HS/VS -/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x77 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x98 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x99 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x3D // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x07 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x22 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x22 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl
//timing setup
WR_REG,THS8200,0x01,0x25,0x98 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x4E // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0x80 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x80 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x4E // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x07 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x70 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x33 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0xA6 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0xA6 // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x03 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0xA7 // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x98 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x73,0x07 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x12 // dtg2_cntl, YPbPr mode, discrete syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 33h, 1600x1200 @ 60Hz, 75.000kHz, 162.000MHz, HS/VS +/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x87 // H-PLL Feedback Divider MSBs - 2160 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0xC0 // HSYNC Output Width - 192 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x09 // AVID Start Pixel LSB - 25 + HS + Hbp = 25 + 192 + 304 = 521 pixels
WR_REG,TVP7000,0x01,0x41,0x02 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x4D // AVID Stop Pixel LSB - AVID Start + Act Pix + 4 = 521 + 1600 + 4 = 2125 pixels
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x32 // VBLK F0 Duration - 50 lines
WR_REG,TVP7000,0x01,0x47,0x32 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl - high DLL freq range
//timing setup
WR_REG,THS8200,0x01,0x25,0xC0 // dtg1_spec_a   192
WR_REG,THS8200,0x01,0x26,0x3E // dtg1_spec_b   hfp - 2 = 64 - 2
WR_REG,THS8200,0x01,0x28,0xF0 // dtg1_spec_d   HS + hbp = 496
WR_REG,THS8200,0x01,0x2B,0x80 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x3E // dtg1_spec_k_lsb  hfp - 2 = 64 - 2
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x08 // dtg1_total_pixel_msb  2160 pixels
WR_REG,THS8200,0x01,0x35,0x70 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x44 // dtg1_frame_field_msb  1250 lines
WR_REG,THS8200,0x01,0x3A,0xE2 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0xE2 // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to 1251 (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x04 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0xE3 // dtg2_bp2_lsb

//discrete output sync control
WR_REG,THS8200,0x01,0x70,0xC0 // dtg2_hlength_lsb  192 pixels
WR_REG,THS8200,0x01,0x73,0x04 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x1B // dtg2_cntl, YPbPr mode, discrete syncs, +HS +VS

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 39h, 1680x1050 @ 60Hz, 64.674kHz, 119.000MHz, HS/VS +/-, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x73 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x20 // Sync Control 1
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x89 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x1D // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x07 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl
//timing setup
WR_REG,THS8200,0x01,0x25,0x20 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x2E // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0x70 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x2E // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x07 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x30 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x44 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x38 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x38 // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x04 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x39 // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x20 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x73,0x07 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x09 // dtg2_cntl, YPbPr mode, discrete syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 3Ah, 1680x1050 @ 60Hz, 65.290kHz, 146.250MHz, HS/VS -/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x8C // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0xB0 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0xE1 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x75 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x27 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x27 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl
//timing setup
WR_REG,THS8200,0x01,0x25,0xB0 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x66 // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0xC8 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x80 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x66 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x08 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0xC0 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x44 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x41 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x41 // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x04 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x42 // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0xB0 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x73,0x07 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x12 // dtg2_cntl, YPbPr mode, discrete syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 44h, 1920x1200 @ 60Hz, 74.038kHz, 154.000MHz, HS/VS +/-, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x82 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x20 // Sync Control 1
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x89 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x0D // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x23 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x23 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl
//timing setup
WR_REG,THS8200,0x01,0x25,0x20 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x2E // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0x70 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x2E // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x08 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x20 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x44 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0xD3 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0xD3 // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x04 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0xD4 // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x20 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x73,0x07 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x09 // dtg2_cntl, YPbPr mode, discrete syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 51h, 1366x768 @ 60Hz, 47.712kHz, 85.500MHz, HS/VS +/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x70 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x8F // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x7D // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0xD7 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl
//timing setup
WR_REG,THS8200,0x01,0x25,0x8F // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x44 // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0x64 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x80 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x44 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x07 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x00 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x33 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x1E // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x1E // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x03 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x1F // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x8F // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x73,0x04 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x1B // dtg2_cntl, YPbPr mode, discrete syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 52h, 1920x1080 @ 60Hz, 67.500kHz, 148.500MHz, HS/VS +/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x89 // H-PLL Feedback Divider MSBs - 2200 pixels
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x2C // HSYNC Output Width - 44 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0xD9 // AVID Start Pixel LSB - 25 + HS + Hbp = 25 + 44 + 148 = 217 pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x5D // AVID Stop Pixel LSB - AVID Start + Act Pix + 4 = 217 + 1920 + 4 = 2141 pixels
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x04 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x04 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration - 50 lines
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl - high DLL freq range
//timing setup
WR_REG,THS8200,0x01,0x25,0x2C // dtg1_spec_a   192
WR_REG,THS8200,0x01,0x26,0x56 // dtg1_spec_b   Hfp - 2 = 88 - 2
WR_REG,THS8200,0x01,0x28,0xC0 // dtg1_spec_d   HS + Hbp = 44 + 148
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x56 // dtg1_spec_k_lsb  hfp - 2 = 88 - 2
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x08 // dtg1_total_pixel_msb  2200 pixels
WR_REG,THS8200,0x01,0x35,0x98 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x44 // dtg1_frame_field_msb  1125 lines
WR_REG,THS8200,0x01,0x3A,0x65 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x65 // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to 1126 (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x04 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x66 // dtg2_bp2_lsb

//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x2C // dtg2_hlength_lsb  44 pixels
WR_REG,THS8200,0x01,0x73,0x06 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x1B // dtg2_cntl, YPbPr mode, discrete syncs, +HS +VS

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 53h, 1600x900 @ 60Hz, 60.000kHz, 108.000MHz, HS/VS +/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x70 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x50 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0xC9 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x05 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x00 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x64 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x64 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl
//timing setup
WR_REG,THS8200,0x01,0x25,0x50 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x16 // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0xB0 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x16 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x07 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x08 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x33 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0xE8 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0xE8 // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x03 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0xE9 // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x50 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x73,0x04 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x1B // dtg2_cntl, YPbPr mode, discrete syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 54h, 2048x1152 @ 60Hz, 72.000kHz, 162.000MHz, HS/VS +/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x8C // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0xA0 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x50 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0xC9 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x03 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x00 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x30 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x30 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl
//timing setup
WR_REG,THS8200,0x01,0x25,0x50 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x18 // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0xB0 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x18 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x08 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0xCA // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x44 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0xB0 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0xB0 // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x04 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0xB1 // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x50 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x73,0x04 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x1B // dtg2_cntl, YPbPr mode, discrete syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 55h, 1280x720 @ 60Hz, 45.000kHz, 74.250MHz, HS/VS +/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x67 // H-PLL Feedback Divider MSBs - 1650 pixels
WR_REG,TVP7000,0x01,0x02,0x20 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x28 // HSYNC Output Width - 40 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x1D // AVID Start Pixel LSB - 25 + HS + Hbp = 25 + 40 + 220 = 285 pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x21 // AVID Stop Pixel LSB - AVID Start + Act Pix + 4 = 285 + 1280 + 4 = 1569 pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x05 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x05 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration - 50 lines
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl - high DLL freq range
//timing setup
WR_REG,THS8200,0x01,0x25,0x28 // dtg1_spec_a   192
WR_REG,THS8200,0x01,0x26,0x6C // dtg1_spec_b   Hfp - 2 = 110 - 2
WR_REG,THS8200,0x01,0x28,0x04 // dtg1_spec_d   HS + Hbp = 40 + 220
WR_REG,THS8200,0x01,0x2B,0x80 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x6C // dtg1_spec_k_lsb  hfp - 2 = 110 - 2
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x06 // dtg1_total_pixel_msb  1650 pixels
WR_REG,THS8200,0x01,0x35,0x72 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x22 // dtg1_frame_field_msb  750 lines
WR_REG,THS8200,0x01,0x3A,0xEE // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0xEE // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to 751 (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x02 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0xEF // dtg2_bp2_lsb

//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x28 // dtg2_hlength_lsb  40 pixels
WR_REG,THS8200,0x01,0x73,0x06 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x1B // dtg2_cntl, YPbPr mode, discrete syncs, +HS +VS

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 56h, 1366x768 @ 60Hz, 48.000kHz, 72.000MHz, HS/VS +/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x5D // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0xC0 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x38 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x8E // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x0C // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x00 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x20 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x20 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl
//timing setup
WR_REG,THS8200,0x01,0x25,0x38 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x0C // dtg1_spec_b
WR_REG,THS8200,0x01,0x28,0x78 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x0C // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x05 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0xDC // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x33 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x20 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x20 // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x03 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x21 // dtg2_bp2_lsb
  
//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x38 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x73,0x04 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x1B // dtg2_cntl, YPbPr mode, discrete syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: n/a, 1920x1080 @ 50Hz, 56.250kHz, 148.500MHz, HS/VS +/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0xA5 // H-PLL Feedback Divider MSBs - 2200 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xD8 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x2C // HSYNC Output Width - 44 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0xD9 // AVID Start Pixel LSB - 25 + HS + Hbp = 25 + 44 + 148 = 217 pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x5D // AVID Stop Pixel LSB - AVID Start + Act Pix + 4 = 217 + 1920 + 4 = 2141 pixels
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x04 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x04 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration - 50 lines
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl - high DLL freq range
//timing setup
WR_REG,THS8200,0x01,0x25,0x2C // dtg1_spec_a   192
WR_REG,THS8200,0x01,0x26,0xFF // dtg1_spec_b (maxed out)  hfp - 2 = 88 - 2
WR_REG,THS8200,0x01,0x28,0xC0 // dtg1_spec_d   HS + Hbp = 44 + 148
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0x0E // dtg1_spec_k_lsb  Hfp - 2 = 88 - 2
WR_REG,THS8200,0x01,0x30,0x02 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x0A // dtg1_total_pixel_msb  2200 pixels
WR_REG,THS8200,0x01,0x35,0x50 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x44 // dtg1_frame_field_msb  1125 lines
WR_REG,THS8200,0x01,0x3A,0x65 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x65 // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to 1126 (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x04 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0x66 // dtg2_bp2_lsb

//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x2C // dtg2_hlength_lsb  44 pixels
WR_REG,THS8200,0x01,0x73,0x06 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x1B // dtg2_cntl, YPbPr mode, discrete syncs, +HS +VS

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: n/a, 1280x720 @ 50Hz, 37.500kHz, 74.250MHz, HS/VS +/+, VGA>YCbCr 444 DS>VGA, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x7B // H-PLL Feedback Divider MSBs - 1650 pixels
WR_REG,TVP7000,0x01,0x02,0xC0 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x28 // HSYNC Output Width - 40 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x1D // AVID Start Pixel LSB - 25 + HS + Hbp = 25 + 192 + 304 = 521 pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x21 // AVID Stop Pixel LSB - AVID Start + Act Pix + 4 = 521 + 1280 + 4 = 2125 pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x05 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x05 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration - 50 lines
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_YCbCr_444_DS_to_VGA_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl - high DLL freq range
//timing setup
WR_REG,THS8200,0x01,0x25,0x28 // dtg1_spec_a   192
WR_REG,THS8200,0x01,0x26,0xFF // dtg1_spec_b (maxed out)   Hfp - 2 = 110 - 2
WR_REG,THS8200,0x01,0x28,0x04 // dtg1_spec_d   HS + Hbp = 40 + 220
WR_REG,THS8200,0x01,0x2B,0x80 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2F,0xB6 // dtg1_spec_k_lsb  Hfp - 2 = 110 - 2
WR_REG,THS8200,0x01,0x30,0x01 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x34,0x07 // dtg1_total_pixel_msb  1650 pixels
WR_REG,THS8200,0x01,0x35,0xBC // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x39,0x22 // dtg1_frame_field_msb  750 lines
WR_REG,THS8200,0x01,0x3A,0xEE // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0xEE // dtg1_field_size_lsb

//generic mode line type setup. Set dtg_bp2_msb and lsb to 751 (lines per frame + 1)
WR_REG,THS8200,0x01,0x50,0x02 // dtg2_bp1_2_msb
WR_REG,THS8200,0x01,0x59,0xEF // dtg2_bp2_lsb

//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x28 // dtg2_hlength_lsb  40 pixels
WR_REG,THS8200,0x01,0x73,0x06 // dtg2_vlength_lsb

//discrete input sync control
WR_REG,THS8200,0x01,0x82,0x1B // dtg2_cntl, YPbPr mode, discrete syncs, +HS +VS

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
