///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
// File Name: TVP7002_THS8200_YPbPr_to_YCbCr_422_ES_to_YPbPr.cmd
// Release Date: 04-22-2013
// For use with the TVP7002+THS8200 EVM Kit

// Description:
// This command file programs the TVP7002 and THS8200 register settings for the following video formats:
//  - All SDTV, EDTV and HDTV YPbPr component video formats up to 162MHz

// The following Include files provide register settings that are the same for all video formats.
//  - TVP7002_default_settings.inc
//  - THS8200_default_settings.inc
//  - TVP7002_YPbPr_to_YCbCr_422_ES_common.inc
//  - THS8200_SDTV_YCbCr_422_ES_to_YPbPr_common.inc
//  - THS8200_HDTV_YCbCr_422_ES_to_YPbPr_common.inc

// The input MUX is configured for YPbPr inputs on the BNC inputs.
// Optimum Phase Sel setting will vary depending on the video source used.
// The THS8200 is set up to not output discrete syncs for YPbPr formats.
// The TVP7002 is set up to use a 27MHz external REFCLK.

// Acronyms:
// RB   Reduced Blanking
// HS   Horizontal Sync
// VS   Vertical Sync
// DS   Discrete Sync
// ES   Embedded Sync
// SOY  Sync on Y
// DMT  Display Monitor Timing
// VGA  Video Graphics Array
////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"Data Enable Output on Pin 22 of TVP7002"

WR_REG,TVP7000,0x01,0x17,0x10 // MISC Control 2, DE out, MISC Control 2, outputs enabled

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"Field ID Output on Pin 22 of TVP7002 (default)"

WR_REG,TVP7000,0x01,0x17,0x00 // MISC Control 2, FID out, MISC Control 2, outputs enabled 

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"*** YPbPr SOY to 20-bit YCbCr 4:2:2 ES to YPbPr SOY settings for TVP7002 + THS8200 ***"

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"480i, 30Hz, 15.734kHz, 13.5MHz, 1x PLL, YPbPr>YCbCr 422 ES>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_422_ES_common.inc
WR_REG,TVP7000,0x01,0x01,0x35 // H-PLL Feedback Divider MSBs  858
WR_REG,TVP7000,0x01,0x02,0xA0 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x18 // H-H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x06 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x10 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x40 // HSYNC Output Width - 64
WR_REG,TVP7000,0x01,0x0E,0x1B // Sync Control 1  HS/VSout--
WR_REG,TVP7000,0x01,0x12,0x03 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x0C // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0x1F // Input Mux Select 2, 2.5MHz SOG LPF, 0.5MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x08 // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x08 // MISC Control 4, Macrovision stripper enabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x18 // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x24 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x83 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//embedded syncs
WR_REG,TVP7000,0x01,0x40,0x95 // AVID Start Pixel LSB  149 (122 + 27)
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x42,0x0F // AVID Stop Pixel LSB    15 ((AVID Start + 720 + 4) - 858)
WR_REG,TVP7000,0x01,0x43,0x00 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x13 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x13 // VBLK F1 Duration
WR_REG,TVP7000,0x01,0x48,0x02 // F-bit F0 Start Line Offset
WR_REG,TVP7000,0x01,0x49,0x01 // F-bit F1 Start Line Offset

//THS8200
INCLUDE,THS8200_SDTV_YCbCr_422_ES_to_YPbPr_common.inc
WR_REG,THS8200,0x01,0x03,0x11 // chip_ctl - low DLL freq range
WR_REG,THS8200,0x01,0x1C,0x4B // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion,
                              // 2x up-sampling, BT.656 output disabled, 20-bit 4:2:2 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x3E // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x14 // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x1E // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x79 // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0x00 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0x01 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2C,0x6B // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x03 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x1B // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x0F // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x0A // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0xAD // dtg1_speg_g_lsb
WR_REG,THS8200,0x01,0x33,0x01 // dtg1_speg_g_msb
WR_REG,THS8200,0x01,0x34,0x03 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x5A // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x80 // dtg1_linecnt_msb - field flip
WR_REG,THS8200,0x01,0x37,0x01 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x84 // dtg1_mode - SDTV 525 lines interlaced
WR_REG,THS8200,0x01,0x39,0x21 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x0D // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x07 // dtg1_field_size_lsb

// discrete output sync control
WR_REG,THS8200,0x01,0x70,0x40 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x71,0x03 // dtg2_hlength_msb_hdly_msb
WR_REG,THS8200,0x01,0x72,0x59 // dtg2_hdly_lsb
WR_REG,THS8200,0x01,0x73,0x04 // dtg2_vlength1_lsb
WR_REG,THS8200,0x01,0x74,0x00 // dtg2_vlength1_msb_vdly1_msb
WR_REG,THS8200,0x01,0x75,0x04 // dtg2_vdly_lsb
WR_REG,THS8200,0x01,0x76,0x04 // dtg2_vlength2_lsb
WR_REG,THS8200,0x01,0x77,0x01 // dtg2_vlength2_msb_vdly2_msb
WR_REG,THS8200,0x01,0x78,0x0B // dtg2_vdly2_lsb

//discrete input sync control - use to align picture
WR_REG,THS8200,0x01,0x79,0x00 // dtg2_hs_in_dly_msb
WR_REG,THS8200,0x01,0x7A,0x43 // dtg2_hs_in_dly_lsb - adjust horizontal
WR_REG,THS8200,0x01,0x7B,0x00 // dtg2_vs_in_dly_msb
WR_REG,THS8200,0x01,0x7C,0x00 // dtg2_vs_in_dly_lsb - adjust vertical
WR_REG,THS8200,0x01,0x82,0x20 // dtg2_cntl, YPbPr mode, embedded syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"480i, 30Hz, 15.734kHz, 13.5MHz, 2x PLL, YPbPr>YCbCr 422 ES>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_422_ES_common.inc
WR_REG,TVP7000,0x01,0x01,0x6B // H-PLL Feedback Divider MSBs  1716
WR_REG,TVP7000,0x01,0x02,0x40 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x10 // H-H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x81 // PHASE SEL(5) CKDI CKDI DIV by 2
WR_REG,TVP7000,0x01,0x05,0x06 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x10 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x40 // HSYNC Output Width - 64
WR_REG,TVP7000,0x01,0x0E,0x1B // Sync Control 1  HS/VSout--
WR_REG,TVP7000,0x01,0x12,0x03 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x0C // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0x1F // Input Mux Select 2, 2.5MHz SOG LPF, 0.5MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x08 // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x08 // MISC Control 4 - Macrovision stripper enabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x18 // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x24 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x83 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//embedded syncs
WR_REG,TVP7000,0x01,0x40,0x90 // AVID Start Pixel LSB  144 (118 + 26)
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x42,0x0A // AVID Stop Pixel LSB    10 ((AVID Start + 720 + 4) - 858)
WR_REG,TVP7000,0x01,0x43,0x00 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x13 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x13 // VBLK F1 Duration
WR_REG,TVP7000,0x01,0x48,0x02 // F-bit F0 Start Line Offset
WR_REG,TVP7000,0x01,0x49,0x01 // F-bit F1 Start Line Offset

//THS8200
INCLUDE,THS8200_SDTV_YCbCr_422_ES_to_YPbPr_common.inc
WR_REG,THS8200,0x01,0x03,0x11 // chip_ctl - low DLL freq range
WR_REG,THS8200,0x01,0x1C,0x4B // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion,
                              // 2x up-sampling, BT.656 output disabled, 20-bit 4:2:2 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x3E // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x14 // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x1E // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x79 // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0x00 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0x01 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2C,0x6B // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x03 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x1B // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x0F // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x0A // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0xAD // dtg1_speg_g_lsb
WR_REG,THS8200,0x01,0x33,0x01 // dtg1_speg_g_msb
WR_REG,THS8200,0x01,0x34,0x03 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x5A // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x80 // dtg1_linecnt_msb - field flip
WR_REG,THS8200,0x01,0x37,0x01 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x84 // dtg1_mode - SDTV 525 lines interlaced
WR_REG,THS8200,0x01,0x39,0x21 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x0D // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x07 // dtg1_field_size_lsb

//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x40 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x71,0x03 // dtg2_hlength_msb_hdly_msb
WR_REG,THS8200,0x01,0x72,0x59 // dtg2_hdly_lsb
WR_REG,THS8200,0x01,0x73,0x04 // dtg2_vlength1_lsb
WR_REG,THS8200,0x01,0x74,0x00 // dtg2_vlength1_msb_vdly1_msb
WR_REG,THS8200,0x01,0x75,0x04 // dtg2_vdly_lsb
WR_REG,THS8200,0x01,0x76,0x04 // dtg2_vlength2_lsb
WR_REG,THS8200,0x01,0x77,0x01 // dtg2_vlength2_msb_vdly2_msb
WR_REG,THS8200,0x01,0x78,0x0B // dtg2_vdly2_lsb

//discrete input sync control - use to align picture
WR_REG,THS8200,0x01,0x79,0x00 // dtg2_hs_in_dly_msb
WR_REG,THS8200,0x01,0x7A,0x43 // dtg2_hs_in_dly_lsb - adjust horizontal
WR_REG,THS8200,0x01,0x7B,0x00 // dtg2_vs_in_dly_msb
WR_REG,THS8200,0x01,0x7C,0x00 // dtg2_vs_in_dly_lsb - adjust vertical
WR_REG,THS8200,0x01,0x82,0x20 // dtg2_cntl, YPbPr mode, embedded syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"480p60, 60Hz, 15.734kHz, 27.0MHz, YPbPr>YCbCr 422 ES>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_422_ES_common.inc
WR_REG,TVP7000,0x01,0x01,0x35 // H-PLL Feedback Divider MSBs  858
WR_REG,TVP7000,0x01,0x02,0xa0 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x18 // H-H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x06 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x10 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x40 // HSYNC Output Width - 64
WR_REG,TVP7000,0x01,0x0E,0x1B // Sync Control 1  HS/VSout--
WR_REG,TVP7000,0x01,0x12,0x03 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x03 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0x1F // Input Mux Select 2, 2.5MHz SOG LPF, 0.5MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x0D // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x08 // MISC Control 4 - Macrovision stripper enabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x18 // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x12 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x43 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3D,0x06 // Line length tolerance
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//embedded syncs
WR_REG,TVP7000,0x01,0x40,0x93 // AVID Start Pixel LSB  147 (122 + 25)
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x42,0x0D // AVID Stop Pixel LSB    13 ((AVID Start + 720 + 4) - 858)
WR_REG,TVP7000,0x01,0x43,0x00 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x44,0x09 // VBLK F0 Start Line Offset  Vfp = 9
WR_REG,TVP7000,0x01,0x45,0x09 // VBLK F1 Start Line Offsett
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration  45 VBLK lines
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration  45
WR_REG,TVP7000,0x01,0x48,0x02 // F-bit F0 Start Line Offset (default)
WR_REG,TVP7000,0x01,0x49,0x01 // F-bit F1 Start Line Offset (default)

//THS8200
INCLUDE,THS8200_SDTV_YCbCr_422_ES_to_YPbPr_common.inc
WR_REG,THS8200,0x01,0x03,0x11 // chip_ctl - low DLL freq range
WR_REG,THS8200,0x01,0x1C,0x4B // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion,
                              // 2x up-sampling, BT.656 output disabled, 20-bit 4:2:2 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x3D // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x10 // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x20 // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x7A // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0xC0 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0x01 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2C,0x90 // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x03 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x1B // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x10 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x00 // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0xAD // dtg1_speg_g_lsb
WR_REG,THS8200,0x01,0x33,0x01 // dtg1_speg_g_msb
WR_REG,THS8200,0x01,0x34,0x03 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x5A // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x00 // dtg1_linecnt_msb
WR_REG,THS8200,0x01,0x37,0x05 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x85 // dtg1_mode - SDTV 525 lines progressive
WR_REG,THS8200,0x01,0x39,0x27 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x0D // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0xFF // dtg1_field_size_lsb

//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x40 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x71,0x03 // dtg2_hlength_msb_hdly_msb
WR_REG,THS8200,0x01,0x72,0x59 // dtg2_hdly_lsb
WR_REG,THS8200,0x01,0x73,0x07 // dtg2_vlength1_lsb
WR_REG,THS8200,0x01,0x74,0x00 // dtg2_vlength1_msb_vdly1_msb
WR_REG,THS8200,0x01,0x75,0x0A // dtg2_vdly_lsb
WR_REG,THS8200,0x01,0x76,0x00 // dtg2_vlength2_lsb
WR_REG,THS8200,0x01,0x77,0xC7 // dtg2_vlength2_msb_vdly2_msb
WR_REG,THS8200,0x01,0x78,0xFF // dtg2_vdly2_lsb

//discrete input sync control - use to align picture
WR_REG,THS8200,0x01,0x79,0x00 // dtg2_hs_in_dly_msb
WR_REG,THS8200,0x01,0x7A,0x44 // dtg2_hs_in_dly_lsb - adjust horizontal
WR_REG,THS8200,0x01,0x7B,0x00 // dtg2_vs_in_dly_msb
WR_REG,THS8200,0x01,0x7C,0x01 // dtg2_vs_in_dly_lsb - adjust vertical
WR_REG,THS8200,0x01,0x82,0x20 // dtg2_cntl, YPbPr mode, embedded syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"720p60, 60Hz, 45kHz, 74.25MHz, YPbPr>YCbCr 422 ES>YPbPr, TVP7002+THS8200"

//TVP7002 4:2:2 out with embedded syncs, CSC bypassed for YPbPr in YCbCr out
INCLUDE,TVP7002_YPbPr_to_YCbCr_422_ES_common.inc
WR_REG,TVP7000,0x01,0x01,0x67 // H-PLL Feedback Divider MSBs  1650
WR_REG,TVP7000,0x01,0x02,0x20 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x32 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x20 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x28 // HSYNC Output Width - 40
WR_REG,TVP7000,0x01,0x0E,0x3F // Sync Control 1 - Select SOG, HS/VSout++
WR_REG,TVP7000,0x01,0x12,0x01 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x00 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0xCF // Input Mux Select 2, SOG LPF bypassed, 4.8MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x53 // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x00 // MISC Control 4 - Macrovision stripper disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x5A // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x07 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x12 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//embedded syncs
WR_REG,TVP7000,0x01,0x40,0x47 // AVID Start Pixel LSB   327 (300 + 27)
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x42,0x4B // AVID Stop Pixel LSB   1611 (AVID Start + 1280 + 4)
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x44,0x05 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x05 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration
WR_REG,TVP7000,0x01,0x48,0x00 // F-bit F0 Start Line Offset (default)
WR_REG,TVP7000,0x01,0x49,0x00 // F-bit F1 Start Line Offset (default)

//THS8200
INCLUDE,THS8200_HDTV_YCbCr_422_ES_to_YPbPr_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl - high DLL freq range
WR_REG,THS8200,0x01,0x1C,0x4B // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion,
                              // 2x up-sampling, BT.656 output disabled, 20-bit 4:2:2 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x28 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x6E // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x28 // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x04 // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0x04 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0xC0 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2C,0x00 // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x00 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x00 // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x6E // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x00 // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0x00 // dtg1_speg_g_lsb
WR_REG,THS8200,0x01,0x33,0x00 // dtg1_speg_g_msb
WR_REG,THS8200,0x01,0x34,0x06 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x72 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x00 // dtg1_linecnt_msb
WR_REG,THS8200,0x01,0x37,0x01 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x82 // dtg1_mode - 720p
WR_REG,THS8200,0x01,0x39,0x27 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0xEE // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0xFF // dtg1_field_size_lsb

//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x28 // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x71,0x06 // dtg2_hlength_msb_hdly_msb
WR_REG,THS8200,0x01,0x72,0x71 // dtg2_hdly_lsb
WR_REG,THS8200,0x01,0x73,0x06 // dtg2_vlength1_lsb
WR_REG,THS8200,0x01,0x74,0x00 // dtg2_vlength1_msb_vdly1_msb
WR_REG,THS8200,0x01,0x75,0x01 // dtg2_vdly_lsb
WR_REG,THS8200,0x01,0x76,0x00 // dtg2_vlength2_lsb
WR_REG,THS8200,0x01,0x77,0x07 // dtg2_vlength2_msb_vdly2_msb
WR_REG,THS8200,0x01,0x78,0xFF // dtg2_vdly2_lsb

//discrete input sync control - use to align picture
WR_REG,THS8200,0x01,0x79,0x00 // dtg2_hs_in_dly_msb
WR_REG,THS8200,0x01,0x7A,0xA2 // dtg2_hs_in_dly_lsb - adjust horizontal
WR_REG,THS8200,0x01,0x7B,0x00 // dtg2_vs_in_dly_msb
WR_REG,THS8200,0x01,0x7C,0x05 // dtg2_vs_in_dly_lsb - adjust vertical
WR_REG,THS8200,0x01,0x82,0x3B // dtg2_cntl, YPbPr mode, embedded syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"1080i30, 30Hz, 33.75kHz, 74.25MHz, YPbPr>YCbCr 422 ES>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_422_ES_common.inc
WR_REG,TVP7000,0x01,0x01,0x89 // PLL DIV MSB  2200
WR_REG,TVP7000,0x01,0x02,0x80 // PLL DIV LSB
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x32 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x20 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x2C // HSYNC Output Width - 44
WR_REG,TVP7000,0x01,0x0E,0x3F // Sync Control 1Force SOG, VS/HSout++
WR_REG,TVP7000,0x01,0x12,0x00 // H-PLL Pre-Coast 
WR_REG,TVP7000,0x01,0x13,0x00 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0xCF // Input Mux Select 2, SOG LPF bypassed, 4.8MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x35 // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x00 // MISC Control 4 - Macrovision stripper disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x5A // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x07 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x13 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//embedded syncs
WR_REG,TVP7000,0x01,0x40,0x07 // AVID Start Pixel LSB  263 (236 + 27) for SOG filter difference
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x42,0x8B // AVID Stop Pixel LSB  2187 (AVID Start + 1920 + 4)
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x44,0x02 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x02 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x16 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x17 // VBLK F1 Duration
WR_REG,TVP7000,0x01,0x48,0x00 // F-bit F0 Start Line Offset (default)
WR_REG,TVP7000,0x01,0x49,0x00 // F-bit F1 Start Line Offset (default)

//THS8200
INCLUDE,THS8200_HDTV_YCbCr_422_ES_to_YPbPr_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl - high DLL freq range
WR_REG,THS8200,0x01,0x1C,0x4B // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion,
                              // 2x up-sampling, BT.656 output disabled, 20-bit 4:2:2 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x2C // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x58 // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x2C // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x84 // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0xC0 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2C,0x00 // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x00 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x00 // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x58 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x00 // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0x58 // dtg1_speg_g_lsb
WR_REG,THS8200,0x01,0x33,0x00 // dtg1_speg_g_msb
WR_REG,THS8200,0x01,0x34,0x08 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x98 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x80 // dtg1_linecnt_msb - field flip
WR_REG,THS8200,0x01,0x37,0x01 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x81 // dtg1_mode - 1080i
WR_REG,THS8200,0x01,0x39,0x42 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x65 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x33 // dtg1_field_size_lsb

//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x2C // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x71,0x08 // dtg2_hlength_msb_hdly_msb
WR_REG,THS8200,0x01,0x72,0x97 // dtg2_hdly_lsb
WR_REG,THS8200,0x01,0x73,0x06 // dtg2_vlength1_lsb
WR_REG,THS8200,0x01,0x74,0x00 // dtg2_vlength1_msb_vdly1_msb
WR_REG,THS8200,0x01,0x75,0x01 // dtg2_vdly_lsb
WR_REG,THS8200,0x01,0x76,0x06 // dtg2_vlength2_lsb
WR_REG,THS8200,0x01,0x77,0x02 // dtg2_vlength2_msb_vdly2_msb
WR_REG,THS8200,0x01,0x78,0x34 // dtg2_vdly2_lsb

//discrete input sync control - use to align picture
WR_REG,THS8200,0x01,0x79,0x00 // dtg2_hs_in_dly_msb
WR_REG,THS8200,0x01,0x7A,0x8C // dtg2_hs_in_dly_lsb - adjust horizontal
WR_REG,THS8200,0x01,0x7B,0x00 // dtg2_vs_in_dly_msb
WR_REG,THS8200,0x01,0x7C,0x01 // dtg2_vs_in_dly_lsb - adjust vertical
WR_REG,THS8200,0x01,0x82,0x3B // dtg2_cntl, YPbPr mode, embedded syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"1080i25, 25Hz, 28.125kHz, 74.25MHz, YPbPr>YCbCr 422 ES>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_422_ES_common.inc
WR_REG,TVP7000,0x01,0x01,0xA5 // H-PLL Feedback Divider MSBs  2640
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x90 // H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2 
WR_REG,TVP7000,0x01,0x05,0x32 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x20 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x2C // HSYNC Output Width - 44
WR_REG,TVP7000,0x01,0x0E,0x3F // Sync Control 1  HSout+
WR_REG,TVP7000,0x01,0x12,0x00 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x01 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0xCF // Input Mux Select 2, SOG LPF bypassed, 4.8MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x35 // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x00 // MISC Control 4 - Macrovision stripper disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x5A // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x07 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x13 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//embedded syncs
WR_REG,TVP7000,0x01,0x40,0x05 // AVID Start Pixel LSB  261 (236 + 25) for SOG filter difference
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x42,0x89 // AVID Stop Pixel LSB  2185 (AVID Start + 1920 + 4)
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x44,0x02 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x02 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x16 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x17 // VBLK F1 Duration
WR_REG,TVP7000,0x01,0x48,0x00 // F-bit F0 Start Line Offset (default)
WR_REG,TVP7000,0x01,0x49,0x00 // F-bit F1 Start Line Offset (default)

//THS8200
INCLUDE,THS8200_HDTV_YCbCr_422_ES_to_YPbPr_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl - high DLL freq range
WR_REG,THS8200,0x01,0x1C,0x4B // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion,
                              // 2x up-sampling, BT.656 output disabled, 20-bit 4:2:2 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x2C // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0xFF // dtg1_spec_b - maxed out
WR_REG,THS8200,0x01,0x27,0x2C // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x84 // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0xC0 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2C,0x00 // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x00 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x00 // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x34 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x01 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x00 // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0x58 // dtg1_speg_g_lsb
WR_REG,THS8200,0x01,0x33,0x00 // dtg1_speg_g_msb
WR_REG,THS8200,0x01,0x34,0x0A // dtg1_total_pixel_msb 2640
WR_REG,THS8200,0x01,0x35,0x50 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x80 // dtg1_linecnt_msb - flip field
WR_REG,THS8200,0x01,0x37,0x01 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x81 // dtg1_mode - 1080i
WR_REG,THS8200,0x01,0x39,0x42 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x65 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x33 // dtg1_field_size_lsb

//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x2C // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x71,0x0A // dtg2_hlength_msb_hdly_msb
WR_REG,THS8200,0x01,0x72,0x4F // dtg2_hdly_lsb
WR_REG,THS8200,0x01,0x73,0x06 // dtg2_vlength1_lsb
WR_REG,THS8200,0x01,0x74,0x00 // dtg2_vlength1_msb_vdly1_msb
WR_REG,THS8200,0x01,0x75,0x01 // dtg2_vdly_lsb
WR_REG,THS8200,0x01,0x76,0x00 // dtg2_vlength2_lsb
WR_REG,THS8200,0x01,0x77,0x00 // dtg2_vlength2_msb_vdly2_msb
WR_REG,THS8200,0x01,0x78,0x00 // dtg2_vdly2_lsb

//discrete input sync control - use to align picture
WR_REG,THS8200,0x01,0x79,0x02 // dtg2_hs_in_dly_msb
WR_REG,THS8200,0x01,0x7A,0x32 // dtg2_hs_in_dly_lsb - adjust horizontal 
WR_REG,THS8200,0x01,0x7B,0x00 // dtg2_vs_in_dly_msb
WR_REG,THS8200,0x01,0x7C,0x02 // dtg2_vs_in_dly_lsb - adjust vertical
WR_REG,THS8200,0x01,0x82,0x3B // dtg2_cntl, YPbPr mode, embedded syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"1080p60, 60Hz, 67.5kHz, 148.5MHz, YPbPr>YCbCr 422 ES>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_422_ES_common.inc
WR_REG,TVP7000,0x01,0x01,0x89 // H-PLL Feedback Divider MSBs  2200
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x32 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x20 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x2C // HSYNC Output Width - 44
WR_REG,TVP7000,0x01,0x0E,0x3F // Sync Control 1  HSout+
WR_REG,TVP7000,0x01,0x12,0x00 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x01 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0xCF // Input Mux Select 2, SOG LPF bypassed, 4.8MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x35 // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x00 // MISC Control 4 - Macrovision stripper disabled
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x5A // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x03 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x09 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x00 // Video Bandwidth Control, maximum B/W selected
//embedded syncs
WR_REG,TVP7000,0x01,0x40,0x07 // AVID Start Pixel LSB  263 (236 + 27) for SOG filter difference
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x42,0x8B // AVID Stop Pixel LSB  2187 (AVID Start + 1920 + 4)
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x44,0x04 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x04 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration
WR_REG,TVP7000,0x01,0x48,0x00 // F-bit F0 Start Line Offset (default)
WR_REG,TVP7000,0x01,0x49,0x00 // F-bit F1 Start Line Offset (default)

//THS8200
INCLUDE,THS8200_HDTV_YCbCr_422_ES_to_YPbPr_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl - high DLL freq range
WR_REG,THS8200,0x01,0x1C,0x5B // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion,
                              // 1x interpolation, BT.656 output disabled, 20-bit 4:2:2 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x2C // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x58 // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x2C // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x84 // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0xC0 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2C,0x00 // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x00 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x00 // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x58 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x00 // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0x58 // dtg1_speg_g_lsb
WR_REG,THS8200,0x01,0x33,0x00 // dtg1_speg_g_msb
WR_REG,THS8200,0x01,0x34,0x08 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x98 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x00 // dtg1_linecnt_msb
WR_REG,THS8200,0x01,0x37,0x01 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x80 // dtg1_mode - 1080p
WR_REG,THS8200,0x01,0x39,0x44 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x65 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x65 // dtg1_field_size_lsb

//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x2C // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x71,0x08 // dtg2_hlength_msb_hdly_msb
WR_REG,THS8200,0x01,0x72,0x97 // dtg2_hdly_lsb
WR_REG,THS8200,0x01,0x73,0x06 // dtg2_vlength1_lsb
WR_REG,THS8200,0x01,0x74,0x00 // dtg2_vlength1_msb_vdly1_msb
WR_REG,THS8200,0x01,0x75,0x01 // dtg2_vdly_lsb
WR_REG,THS8200,0x01,0x76,0x00 // dtg2_vlength2_lsb
WR_REG,THS8200,0x01,0x77,0x00 // dtg2_vlength2_msb_vdly2_msb
WR_REG,THS8200,0x01,0x78,0x00 // dtg2_vdly2_lsb

//discrete input sync  control - use to align picture
WR_REG,THS8200,0x01,0x79,0x00 // dtg2_hs_in_dly_msb
WR_REG,THS8200,0x01,0x7A,0x7A // dtg2_hs_in_dly_lsb - adjust horizontal
WR_REG,THS8200,0x01,0x7B,0x00 // dtg2_vs_in_dly_msb
WR_REG,THS8200,0x01,0x7C,0x04 // dtg2_vs_in_dly_lsb - adjust vertical
WR_REG,THS8200,0x01,0x82,0x3B // dtg2_cntl, YPbPr mode, embedded syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"1080p50, 50Hz, 56.25kHz, 148.5MHz, YPbPr>YCbCr 422 ES>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_422_ES_common.inc
WR_REG,TVP7000,0x01,0x01,0xA5 // H-PLL Feedback Divider MSBs  2640
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x90 // H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x32 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x20 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x2C // HSYNC Output Width - 44
WR_REG,TVP7000,0x01,0x0E,0x3F // Sync Control 1  HSout+
WR_REG,TVP7000,0x01,0x12,0x00 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x01 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0xCF // Input Mux Select 2, SOG LPF bypassed, 4.8MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x35 // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x00 // MISC Control 4 - Macrovision stripper disabled
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x5A // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x03 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x09 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x00 // Video Bandwidth Control, maximum B/W selected
//embedded syncs
WR_REG,TVP7000,0x01,0x40,0x05 // AVID Start Pixel LSB  261 (236 + 25) for SOG filter difference
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x42,0x89 // AVID Stop Pixel LSB  2185 (AVID Start + 1920 + 4)
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x44,0x04 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x04 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration
WR_REG,TVP7000,0x01,0x48,0x00 // F-bit F0 Start Line Offset (default)
WR_REG,TVP7000,0x01,0x49,0x00 // F-bit F1 Start Line Offset (default)

//THS8200
INCLUDE,THS8200_HDTV_YCbCr_422_ES_to_YPbPr_common.inc
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl - high DLL freq range
WR_REG,THS8200,0x01,0x1C,0x5B // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion,
                              // 1x interpolation, BT.656 output disabled, 20-bit 4:2:2 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x2C // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0xFF // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x2C // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x84 // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0xC0 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2C,0x00 // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x00 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x00 // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x10 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x02 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x00 // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0x58 // dtg1_speg_g_lsb
WR_REG,THS8200,0x01,0x33,0x00 // dtg1_speg_g_msb
WR_REG,THS8200,0x01,0x34,0x0A // dtg1_total_pixel_msb  2640
WR_REG,THS8200,0x01,0x35,0x50 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x00 // dtg1_linecnt_msb
WR_REG,THS8200,0x01,0x37,0x01 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x80 // dtg1_mode - 1080p
WR_REG,THS8200,0x01,0x39,0x44 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x65 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x65 // dtg1_field_size_lsb

//discrete output sync control
WR_REG,THS8200,0x01,0x70,0x2C // dtg2_hlength_lsb
WR_REG,THS8200,0x01,0x71,0x0A // dtg2_hlength_msb_hdly_msb
WR_REG,THS8200,0x01,0x72,0x4F // dtg2_hdly_lsb
WR_REG,THS8200,0x01,0x73,0x06 // dtg2_vlength1_lsb
WR_REG,THS8200,0x01,0x74,0x00 // dtg2_vlength1_msb_vdly1_msb
WR_REG,THS8200,0x01,0x75,0x01 // dtg2_vdly1_lsb
WR_REG,THS8200,0x01,0x76,0x00 // dtg2_vlength2_lsb
WR_REG,THS8200,0x01,0x77,0x00 // dtg2_vlength2_msb_vdly2_msb
WR_REG,THS8200,0x01,0x78,0x00 // dtg2_vdly2_lsb

//discrete input sync control - use to align picture
WR_REG,THS8200,0x01,0x79,0x02 // dtg2_hs_in_dly_msb
WR_REG,THS8200,0x01,0x7A,0x32 // dtg2_hs_in_dly_lsb - adjust horizontal
WR_REG,THS8200,0x01,0x7B,0x00 // dtg2_vs_in_dly_msb
WR_REG,THS8200,0x01,0x7C,0x04 // dtg2_vs_in_dly_lsb - adjust vertical
WR_REG,THS8200,0x01,0x82,0x3B // dtg2_cntl, YPbPr mode, embedded syncs

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
