////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
// File Name: TVP7002_THS8200_YPbPr_to_YCbCr_444_DS_to_YPbPr.cmd
// Release Date: 04-22-2013
// For use with the TVP7002+THS8200 EVM Kit

// Description:
// This command file programs the TVP7002 and THS8200 register settings for the following video formats:
//   - All SDTV, EDTV and HDTV YPbPr component video formats up to 162MHz

// The following Include files provide register settings that are the same for all video formats.
//  - TVP7002_default_settings.inc
//  - THS8200_default_settings.inc
//  - TVP7002_YPbPr_to_YCbCr_444_DS_common.inc
//  - THS8200_SDTV_YCbCr_444_DS_to_YPbPr_common.inc
//  - THS8200_HDTV_YCbCr_444_DS_to_YPbPr_common.inc

// The input MUX is configured for YPbPr inputs on the BNC inputs.
// Optimum Phase Sel setting will vary depending on the video source used.
// The THS8200 is set up to not output discrete syncs for YPbPr formats.
// The TVP7002 is set up to use a 27MHz external REFCLK.

// Acronyms:
// RB   Reduced Blanking
// HS   Horizontal Sync
// VS   Vertical Sync
// DS   Discrete Sync
// ES   Embedded Sync
// SOY  Sync on Y
// DMT  Display Monitor Timing
// VGA  Video Graphics Array
////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"*** YPbPr SOY to 30-bit YCbCr 4:4:4 DS to YPbPr SOY settings for TVP7002 + THS8200 ***"

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"480i, 30Hz, 15.734kHz, 13.5MHz, 1x PLL, YPbPr>YCbCr 444 DS>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_444_DS_common.inc  // include settings used for all YPbPr input
WR_REG,TVP7000,0x01,0x01,0x35 // H-PLL Feedback Divider MSBs  858
WR_REG,TVP7000,0x01,0x02,0xA0 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x18 // H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x06 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x10 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x40 // HSYNC Output Width - 64
WR_REG,TVP7000,0x01,0x0E,0x00 // Sync Control 1    HSout- VSout-
WR_REG,TVP7000,0x01,0x12,0x03 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x03 // H-PLL Post-Coast 
WR_REG,TVP7000,0x01,0x1A,0x1F // Input Mux Select 2, 2.5MHz SOG LPF, 0.5MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x0C // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x08 // MISC Control 4, Macrovision stripper enabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x18 // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x24 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x83 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//DE
WR_REG,TVP7000,0x01,0x40,0x83 // AVID Start Pixel LSB  131 (118 + 13) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x53 // AVID Stop Pixel LSB   851 (AVID Start + 720) pixels
WR_REG,TVP7000,0x01,0x43,0x03 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x04 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x04 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x16 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x17 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_SDTV_YCbCr_444_DS_to_YPbPr_common.inc  // include common settings used for all SD/EDTV formats
WR_REG,THS8200,0x01,0x03,0x11 // chip_ctl - low DLL freq range
WR_REG,THS8200,0x01,0x1C,0x68 // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion bypassed,
                              // 2x up-sampling, BT.656 output disabled, 30-bit 4:4:4 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x3D // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x14 // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x1D // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x7C // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0x00 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0x01 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2C,0x6C // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x01 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x8D // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x14 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x0A // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0xAD // dtg1_spec_g_lsb
WR_REG,THS8200,0x01,0x33,0x01 // dtg1_spec_g_msb
WR_REG,THS8200,0x01,0x34,0x03 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x5A // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x80 // dtg1_linecnt_msb
WR_REG,THS8200,0x01,0x37,0x04 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x84 // dtg1_mode - SDTV 525 lines interlaced
WR_REG,THS8200,0x01,0x39,0x21 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x0D // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x07 // dtg1_field_size_lsb

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"480i, 30Hz, 15.734kHz, 27MHz, 2x PLL, YPbPr>YCbCr 444 DS>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_444_DS_common.inc  // include settings used for all YPbPr input
WR_REG,TVP7000,0x01,0x01,0x6B // H-PLL Feedback Divider MSBs  1716
WR_REG,TVP7000,0x01,0x02,0x40 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x10 // H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x81 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x06 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x10 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x40 // HSYNC Output Width - 64
WR_REG,TVP7000,0x01,0x0E,0x00 // Sync Control 1    HSout- VSout-
WR_REG,TVP7000,0x01,0x12,0x03 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x03 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0x1F // Input Mux Select 2, 2.5MHz SOG LPF, 0.5MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x0C // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x08 // MISC Control 4, Macrovision stripper enabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x18 // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x24 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x83 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//DE
WR_REG,TVP7000,0x01,0x40,0x83 // AVID Start Pixel LSB  131 (118 + 13) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x53 // AVID Stop Pixel LSB   851 (AVID Start + 720) pixels
WR_REG,TVP7000,0x01,0x43,0x03 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x04 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x04 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x16 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x17 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_SDTV_YCbCr_444_DS_to_YPbPr_common.inc  // include common settings used for all SD/EDTV formats
WR_REG,THS8200,0x01,0x03,0x11 // chip_ctl - low DLL freq range
WR_REG,THS8200,0x01,0x1C,0x68 // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion bypassed,
                              // 2x up-sampling, BT.656 output disabled, 30-bit 4:4:4 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x3D // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x14 // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x1D // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x7C // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0x00 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0x01 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2C,0x6C // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x01 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x8D // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x14 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x0A // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0xAD // dtg1_spec_g_lsb
WR_REG,THS8200,0x01,0x33,0x01 // dtg1_spec_g_msb
WR_REG,THS8200,0x01,0x34,0x03 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x5A // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x80 // dtg1_linecnt_msb
WR_REG,THS8200,0x01,0x37,0x04 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x84 // dtg1_mode - SDTV 525 lines interlaced
WR_REG,THS8200,0x01,0x39,0x21 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x0D // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x07 // dtg1_field_size_lsb

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"576i, 25Hz, 15.625kHz, 13.5MHz, YPbPr>YCbCr 444 DS>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_444_DS_common.inc  // include settings used for all YPbPr input
WR_REG,TVP7000,0x01,0x01,0x36 // H-PLL Feedback Divider MSBs  864
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x18 // H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x06 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x10 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x40 // HSYNC Output Width - 64
WR_REG,TVP7000,0x01,0x0E,0x00 // Sync Control 1    HSout- VSout-
WR_REG,TVP7000,0x01,0x12,0x03 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x03 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0x1F // Input Mux Select 2, 2.5MHz SOG LPF, 0.5MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x0A // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x08 // MISC Control 4, Macrovision stripper enabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x18 // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x24 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x83 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//DE
WR_REG,TVP7000,0x01,0x40,0x83 // AVID Start Pixel LSB  131 (118 + 13) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x53 // AVID Stop Pixel LSB   851 (AVID Start + 720) pixels
WR_REG,TVP7000,0x01,0x43,0x03 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x04 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x04 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x16 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x17 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_SDTV_YCbCr_444_DS_to_YPbPr_common.inc  // include common settings used for all SD/EDTV formats
WR_REG,THS8200,0x01,0x03,0x11 // chip_ctl - low DLL freq range
WR_REG,THS8200,0x01,0x1C,0x68 // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion bypassed,
                              // 2x up-sampling, BT.656 output disabled, 30-bit 4:4:4 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x3E // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x58 // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x20 // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x83 // dtg1_spec_d
WR_REG,THS8200,0x01,0x2A,0xC0 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0x01 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2C,0x70 // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x03 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x1B // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x0D // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x31,0x0A // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0xB0 // dtg1_spec_g_lsb
WR_REG,THS8200,0x01,0x33,0x01 // dtg1_spec_g_msb
WR_REG,THS8200,0x01,0x34,0x03 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x60 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x80 // dtg1_linecnt_msb
WR_REG,THS8200,0x01,0x37,0x01 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x88 // dtg1_mode - SDTV 625 lines interlaced
WR_REG,THS8200,0x01,0x39,0x21 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x71 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x38 // dtg1_field_size_lsb

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"480p60, 60Hz, 31.468kHz, 27Mz, 1x PLL, YPbPr>YCbCr 444 DS>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_444_DS_common.inc  // inlude settings used for all YPbPr input
WR_REG,TVP7000,0x01,0x01,0x35 // H-PLL Feedback Divider MSBs    858
WR_REG,TVP7000,0x01,0x02,0xA0 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x18 // H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x06 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x10 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x40 // HSYNC Output Width - 64
WR_REG,TVP7000,0x01,0x0E,0x00 // Sync Control 1    HSout- VSout-
WR_REG,TVP7000,0x01,0x12,0x03 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x03 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0x1F // Input Mux Select 2, 2.5MHz SOG LPF, 0.5MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x0A // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x08 // MISC Control 4, Macrovision stripper enabled on
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x18 // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x12 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x43 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//DE
WR_REG,TVP7000,0x01,0x40,0x84 // AVID Start Pixel LSB  132 (122 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x54 // AVID Stop Pixel LSB   852 (AVID Start + 720) pixels
WR_REG,TVP7000,0x01,0x43,0x03 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x09 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x09 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2d // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x2d // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_SDTV_YCbCr_444_DS_to_YPbPr_common.inc  // include common settings used for all SD/EDTV formats
WR_REG,THS8200,0x01,0x03,0x11 // chip_ctl - low DLL freq range 
WR_REG,THS8200,0x01,0x1C,0x68 // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion bypassed,
                              // 2x up-sampling, BT.656 output disabled, 30-bit 4:4:4 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x3D // dtg1_spec_a, 61 = 0x3D
WR_REG,THS8200,0x01,0x26,0x10 // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x20 // dtg1_spec_c, 32 = 0x20
WR_REG,THS8200,0x01,0x28,0x7A // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0xC0 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0x01 // dtg1_spec_h_msb, (858 - 58?)/2 = 400
WR_REG,THS8200,0x01,0x2C,0x90 // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x03 // dtg1_spec_i_msb, 858 - 63 = 795
WR_REG,THS8200,0x01,0x2E,0x1B // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x10 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x00 // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0xAD // dtg1_spec_g_lsb
WR_REG,THS8200,0x01,0x33,0x01 // dtg1_spec_g_msb
WR_REG,THS8200,0x01,0x34,0x03 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x5A // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x80 // dtg1_linecnt_msb
WR_REG,THS8200,0x01,0x37,0x07 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x89 // dtg1_mode - Generic SDTV
WR_REG,THS8200,0x01,0x39,0x27 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x0D // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0xFF // dtg1_field_size_lsb

// Generic mode used to allow CGMS insertion
WR_REG,THS8200,0x01,0x50,0x00 // dtg2_bp1_2_msb (default)
WR_REG,THS8200,0x01,0x51,0x02 // dtg2_bp3_4_msb
WR_REG,THS8200,0x01,0x52,0x00 // dtg2_bp5_6_msb (default)
WR_REG,THS8200,0x01,0x58,0x07 // dtg2_bp1_lsb
WR_REG,THS8200,0x01,0x59,0x0D // dtg2_bp2_lsb
WR_REG,THS8200,0x01,0x5A,0x2B // dtg2_bp3_lsb
WR_REG,THS8200,0x01,0x5B,0x0E // dtg2_bp4_lsb
WR_REG,THS8200,0x01,0x68,0x9A // dtg2_linetype1
WR_REG,THS8200,0x01,0x69,0x00 // dtg2_linetype2 (default)
WR_REG,THS8200,0x01,0x6A,0x00 // dtg2_linetype3 (default)
//WR_REG,THS8200,0x01,0x6B,0x00 // dtg2_linetype4 (default)

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"480p60, 60Hz, 31.468kHz, 54Mz, 2x PLL, YPbPr>YCbCr 444 DS>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_444_DS_common.inc  // include settings used for all YPbPr input
WR_REG,TVP7000,0x01,0x01,0x6B // H-PLL Feedback Divider MSBs  1716
WR_REG,TVP7000,0x01,0x02,0x40 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x50 // H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x81 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x06 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x10 // Clamp Width 
WR_REG,TVP7000,0x01,0x07,0x40 // HSYNC Output Width - 64
WR_REG,TVP7000,0x01,0x0E,0x00 // Sync Control 1    HSout- VSout-
WR_REG,TVP7000,0x01,0x12,0x03 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x03 // H-PLL Post-Coast 
WR_REG,TVP7000,0x01,0x1A,0x1F // Input Mux Select 2, 2.5MHz SOG LPF, 0.5MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x0A // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x08 // MISC Control 4, Macrovision stripper enabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x18 // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x12 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x43 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//DE
WR_REG,TVP7000,0x01,0x40,0x84 // AVID Start Pixel LSB  132 (122 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x54 // AVID Stop Pixel LSB   852 (AVID Start + 720) pixels
WR_REG,TVP7000,0x01,0x43,0x03 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x09 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x09 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_SDTV_YCbCr_444_DS_to_YPbPr_common.inc  // include common settings used for all SD/EDTV formats
WR_REG,THS8200,0x01,0x03,0x11 // chip_ctl - low DLL freq range
WR_REG,THS8200,0x01,0x1C,0x68 // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion bypassed,
                              // 2x up-sampling, BT.656 output disabled, 30-bit 4:4:4 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x3D // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x10 // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x20 // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x7A // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0xC0 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0x01 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2C,0x90 // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x03 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x1B // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x10 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x00 // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0xAD // dtg1_spec_g_lsb
WR_REG,THS8200,0x01,0x33,0x01 // dtg1_spec_g_msb
WR_REG,THS8200,0x01,0x34,0x03 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x5A // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x80 // dtg1_linecnt_msb
WR_REG,THS8200,0x01,0x37,0x07 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x89 // dtg1_mode - Generic SDTV
WR_REG,THS8200,0x01,0x39,0x27 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x0D // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0xFF // dtg1_field_size_lsb

// Generic mode used to allow CGMS insertion
WR_REG,THS8200,0x01,0x50,0x00 // dtg2_bp1_2_msb (default)
WR_REG,THS8200,0x01,0x51,0x02 // dtg2_bp3_4_msb
WR_REG,THS8200,0x01,0x52,0x00 // dtg2_bp5_6_msb (default)
WR_REG,THS8200,0x01,0x58,0x07 // dtg2_bp1_lsb //assumes 483 active lines
WR_REG,THS8200,0x01,0x59,0x0D // dtg2_bp2_lsb
WR_REG,THS8200,0x01,0x5A,0x2B // dtg2_bp3_lsb
WR_REG,THS8200,0x01,0x5B,0x0E // dtg2_bp4_lsb
WR_REG,THS8200,0x01,0x68,0x9A // dtg2_linetype1
WR_REG,THS8200,0x01,0x69,0x00 // dtg2_linetype2 (default)
WR_REG,THS8200,0x01,0x6A,0x00 // dtg2_linetype3 (default)
//WR_REG,THS8200,0x01,0x6B,0x00 // dtg2_linetype4 (default)

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"576p50, 50Hz, 31.25kHz, 27MHz, YPbPr>YCbCr 444 DS>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_444_DS_common.inc  // include settings used for all YPbPr input
WR_REG,TVP7000,0x01,0x01,0x36 // H-PLL Feedback Divider MSBs  864
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x18 // H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x06 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x10 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x40 // HSYNC Output Width - 64
WR_REG,TVP7000,0x01,0x0E,0x00 // Sync Control 1    HSout- VSout-
WR_REG,TVP7000,0x01,0x12,0x03 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x03 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0x1F // Input Mux Select 2, 2.5MHz SOG LPF, 0.5MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x0A // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x08 // MISC Control 4, Macrovision stripper enabled on
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x2D,0x00 // Coarse Clamp OFF
WR_REG,TVP7000,0x01,0x2E,0x80 // SOG Clamp ON
WR_REG,TVP7000,0x01,0x31,0x18 // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x12 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x43 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//DE
WR_REG,TVP7000,0x01,0x40,0x8A // AVID Start Pixel LSB  138 (128 + 10) pixels (marginal)
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x5A // AVID Stop Pixel LSB   858 (AVID Start + 720) pixels (marginal)
WR_REG,TVP7000,0x01,0x43,0x03 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x05 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x05 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x20 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x20 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_SDTV_YCbCr_444_DS_to_YPbPr_common.inc  // include common settings used for all SD/EDTV formats
WR_REG,THS8200,0x01,0x03,0x11 // chip_ctl - low DLL freq range
WR_REG,THS8200,0x01,0x1C,0x68 // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion bypassed,
                              // 2x up-sampling, BT.656 output disabled, 30-bit 4:4:4 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x3E // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x0E // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x20 // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x85 // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0xC0 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0x01 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2C,0x90 // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x03 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x1F // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x0E // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x00 // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0xB0 // dtg1_spec_g_lsb
WR_REG,THS8200,0x01,0x33,0x01 // dtg1_spec_g_msb
WR_REG,THS8200,0x01,0x34,0x03 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x60 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x80 // dtg1_linecnt_msb
WR_REG,THS8200,0x01,0x37,0x06 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x89 // dtg1_mode - Generic SDTV
WR_REG,THS8200,0x01,0x39,0x27 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x71 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0xFF // dtg1_field_size_lsb

//Generic mode setup        
WR_REG,THS8200,0x01,0x50,0x00 // dtg2_bp1_2_msb (default)
WR_REG,THS8200,0x01,0x51,0x02 // dtg2_bp3_4_msb
WR_REG,THS8200,0x01,0x52,0x00 // dtg2_bp5_6_msb (default)
WR_REG,THS8200,0x01,0x58,0x06 // dtg2_bp1_lsb
WR_REG,THS8200,0x01,0x59,0x0B // dtg2_bp2_lsb
WR_REG,THS8200,0x01,0x5A,0x32 // dtg2_bp3_lsb
WR_REG,THS8200,0x01,0x5B,0x72 // dtg2_bp4_lsb
WR_REG,THS8200,0x01,0x5C,0x00 // dtg2_bp5_lsb (default)
WR_REG,THS8200,0x01,0x68,0x9A // dtg2_linetype1
WR_REG,THS8200,0x01,0x69,0x00 // dtg2_linetype2 (default)
WR_REG,THS8200,0x01,0x6A,0x00 // dtg2_linetype3 (default)
WR_REG,THS8200,0x01,0x6B,0x00 // dtg2_linetype4 (default)

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"720p60, 60Hz, 45kHz, 74.25MHz, YPbPr>YCbCr 444 DS>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_444_DS_common.inc  // include settings used for all YPbPr input
WR_REG,TVP7000,0x01,0x01,0x67 // H-PLL Feedback Divider MSBs  1650
WR_REG,TVP7000,0x01,0x02,0x20 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // VCO2_CP3_RR_CP_R
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x32 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x20 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x28 // HSYNC Output Width - 40
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1    HSout+ VSout+
WR_REG,TVP7000,0x01,0x12,0x01 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x00 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0xCF // Input Mux Select 2, SOG LPF bypassed, 4.8MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x35 // HSOUT Output Start (13 + 40)
WR_REG,TVP7000,0x01,0x22,0x00 // MISC Control 4, Macrovision stripper enabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x5A // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x07 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x12 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//DE Setup
WR_REG,TVP7000,0x01,0x40,0x39 // AVID Start Pixel LSB  313 (300 + 13) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x39 // AVID Stop Pixel LSB  1593 (AVID Start + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x05 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x05 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration 30 lines
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_HDTV_YCbCr_444_DS_to_YPbPr_common.inc  // include common settings used for all HDTV formats
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl - high DLL freq range
WR_REG,THS8200,0x01,0x1C,0x68 // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion bypassed,
                              // 2x up-sampling, BT.656 output disabled, 30-bit 4:4:4 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x28 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x6E // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x28 // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x04 // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0x04 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0xC0 // dtg1_spec_deh_msb
WR_REG,THS8200,0x01,0x2C,0x00 // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x00 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x00 // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x6E // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x00 // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0x58 // dtg1_spec_g_lsb, was:0x00
WR_REG,THS8200,0x01,0x33,0x00 // dtg1_spec_g_msb
WR_REG,THS8200,0x01,0x34,0x06 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x72 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x80 // dtg1_linecnt_msb
WR_REG,THS8200,0x01,0x37,0x01 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x82 // dtg1_mode - 720p
WR_REG,THS8200,0x01,0x39,0x27 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0xEE // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0xFF // dtg1_field_size_lsb

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"720p50, 50Hz, 37.5kHz, 74.25MHz, YPbPr>YCbCr 444 DS>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_444_DS_common.inc  // include settings used for all YPbPr input
WR_REG,TVP7000,0x01,0x01,0x7B // H-PLL Feedback Divider MSBs  1980
WR_REG,TVP7000,0x01,0x02,0xC0 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // VCO2_CP3_RR_CP_R
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x32 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x20 // Clamp Width 
WR_REG,TVP7000,0x01,0x07,0x28 // HSYNC Output Width - 40
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1    HSout+ VSout+
WR_REG,TVP7000,0x01,0x12,0x01 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x00 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0xCF // Input Mux Select 2, SOG LPF bypassed, 4.8MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x35 // HSOUT Output Start (13 + 40)
WR_REG,TVP7000,0x01,0x22,0x00 // MISC Control 4, Macrovision stripper disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x5A // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x07 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x12 // Macrovision Stripper Width when 27MHz EXT REFCLK is used

WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
// DE Setup
WR_REG,TVP7000,0x01,0x40,0x39 // VID Start Pixel LSB  313 (300 + 13) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // VID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x39 // AVID Stop Pixel LSB  1593 (AVID Start + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x05 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x05 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration 30 lines
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_HDTV_YCbCr_444_DS_to_YPbPr_common.inc  // include common settings used for all HDTV formats
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl - high DLL freq range
WR_REG,THS8200,0x01,0x1C,0x68 // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion bypassed,
                              // 2x up-sampling, BT.656 output disabled, 30-bit 4:4:4 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x28 // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0xFF // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x28 // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x04 // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0x04 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0xC0 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2C,0x00 // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x00 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x00 // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0xB8 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x01 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x00 // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0x58 // dtg1_spec_g_lsb, was:0x00
WR_REG,THS8200,0x01,0x33,0x00 // dtg1_spec_g_msb
WR_REG,THS8200,0x01,0x34,0x07 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0xBC // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x80 // dtg1_linecnt_msb
WR_REG,THS8200,0x01,0x37,0x01 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x82 // dtg1_mode - 720p
WR_REG,THS8200,0x01,0x39,0x27 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0xEE // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0xFF // dtg1_field_size_lsb

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"1080i30, 30Hz, 33.75kHz, 74.25MHz, YPbPr>YCbCr 444 DS>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_444_DS_common.inc  // include settings used for all YPbPr input
WR_REG,TVP7000,0x01,0x01,0x89 // H-PLL Feedback Divider MSBs   2200
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x32 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x20 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x2C // HSYNC Output Width - 44
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1    HSout+ VSout+
WR_REG,TVP7000,0x01,0x0F,0x2E // PLL and CLAMP CONTROL 
WR_REG,TVP7000,0x01,0x12,0x01 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x00 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0xCF // Input Mux Select 2, SOG LPF bypassed, 4.8MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x39 // HSOUT Output Start (13 + 44)
WR_REG,TVP7000,0x01,0x22,0x00 // MISC Control 4, Macrovision stripper disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x2D,0x00 // Coarse Clamp OFF
WR_REG,TVP7000,0x01,0x2E,0x80 // SOG Clamp ON
WR_REG,TVP7000,0x01,0x31,0x5A // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x07 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x13 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//DE
WR_REG,TVP7000,0x01,0x40,0xF9 // AVID Start Pixel LSB  249 (236 + 13) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x79 // AVID Stop Pixel LSB  2169 (AVID Start + 1920) pixels
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x02 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x02 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x16 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x17 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_HDTV_YCbCr_444_DS_to_YPbPr_common.inc  // include common settings used for all HDTV formats
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl - high DLL freq range
WR_REG,THS8200,0x01,0x1C,0x68 // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion bypassed,
                              // 2x up-sampling, BT.656 output disabled, 30-bit 4:4:4 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x2C // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x58 // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x2C // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x84 // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0xC0 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2C,0x00 // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x00 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x00 // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x58 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x00 // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0x58 // dtg1_spec_g_lsb
WR_REG,THS8200,0x01,0x33,0x00 // dtg1_spec_g_msb
WR_REG,THS8200,0x01,0x34,0x08 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x98 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x80 // dtg1_linecnt_msb
WR_REG,THS8200,0x01,0x37,0x01 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x81 // dtg1_mode - 1080i
WR_REG,THS8200,0x01,0x39,0x42 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x65 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x33 // dtg1_field_size_lsb

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"1080i25, 25Hz, 28.125kHz, 74.25MHz, YPbPr>YCbCr 444 DS>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_444_DS_common.inc  // include settings used for all YPbPr input
WR_REG,TVP7000,0x01,0x01,0xA5 // H-PLL Feedback Divider MSBs   2640
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x90 // H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2 
WR_REG,TVP7000,0x01,0x05,0x32 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x20 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x2C // HSYNC Output Width - 44
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1    HSout+ VSout+
WR_REG,TVP7000,0x01,0x0F,0x2E // PLL and CLAMP CONTROL 
WR_REG,TVP7000,0x01,0x12,0x01 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x00 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0xCF // Input Mux Select 2, SOG LPF bypassed, 4.8MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x39 // HSOUT Output Start (13 + 44)
WR_REG,TVP7000,0x01,0x22,0x00 // MISC Control 4, Macrovision stripper disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x5A // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x07 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x13 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//DE
WR_REG,TVP7000,0x01,0x40,0xF9 // AVID Start Pixel LSB  249 (236 + 13) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x79 // AVID Stop Pixel LSB  2169 (AVID Start + 1920) pixels
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x02 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x02 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x16 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x17 // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_HDTV_YCbCr_444_DS_to_YPbPr_common.inc  // include common settings used for all HDTV formats
WR_REG,THS8200,0x01,0x03,0x01 // chip_ctl - high DLL freq range
WR_REG,THS8200,0x01,0x1C,0x68 // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion bypassed,
                              // 2x up-sampling, BT.656 output disabled, 30-bit 4:4:4 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x2C // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0xFF // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x2C // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x84 // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0xC0 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2C,0x00 // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x00 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x00 // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x34 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x01 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x00 // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0x58 // dtg1_spec_g_lsb
WR_REG,THS8200,0x01,0x33,0x00 // dtg1_spec_g_msb
WR_REG,THS8200,0x01,0x34,0x0A // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x50 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x80 // dtg1_linecnt_msb
WR_REG,THS8200,0x01,0x37,0x01 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x81 // dtg1_mode - 1080i
WR_REG,THS8200,0x01,0x39,0x42 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x65 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x33 // dtg1_field_size_lsb

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"1080p60, 60Hz, 67.5kHz, 148.5MHz, YPbPr>YCbCr 444 DS>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_444_DS_common.inc  // include settings used for all YPbPr input
WR_REG,TVP7000,0x01,0x01,0x89 // H-PLL Feedback Divider MSBs 2200
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x32 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x20 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x2C // HSYNC Output Width - 44
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1    HSout+ VSout+
WR_REG,TVP7000,0x01,0x12,0x01 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x00 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0xCF // Input Mux Select 2, SOG LPF bypassed, 4.8MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x39 // HSOUT Output Start(13 + 44)
WR_REG,TVP7000,0x01,0x22,0x00 // MISC Control 4, Macrovision stripper disabled
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x5A // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x03 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x09 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x00 // Video Bandwidth Control (default), maximum B/W selected
//DE
WR_REG,TVP7000,0x01,0x40,0xF9 // AVID Start Pixel LSB  249 (236 + 13) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x79 // AVID Stop Pixel LSB  2169 (AVID Start + 1920) pixels
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x04 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x04 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration  45
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_HDTV_YCbCr_444_DS_to_YPbPr_common.inc  // include common settings used for all HDTV formats
WR_REG,THS8200,0x01,0x03,0x81 // chip_ctl - high DLL freq range
WR_REG,THS8200,0x01,0x1C,0x78 // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion bypassed,
                              // 1x oversampling, BT.656 output disabled, 30-bit 4:4:4 input format
//timing setup
WR_REG,THS8200,0x01,0x25,0x2C // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x58 // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x2C // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x84 // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0xC0 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2C,0x00 // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x00 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x00 // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x58 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x00 // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0x58 // dtg1_spec_g_lsb
WR_REG,THS8200,0x01,0x33,0x00 // dtg1_spec_g_msb
WR_REG,THS8200,0x01,0x34,0x08 // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x98 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x80 // dtg1_linecnt_msb
WR_REG,THS8200,0x01,0x37,0x01 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x80 // dtg1_mode - 1080p
WR_REG,THS8200,0x01,0x39,0x44 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x65 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x65 // dtg1_field_size_lsb

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"1080p50, 50Hz, 56.25kHz, 148.5MHz, YPbPr>YCbCr 444 DS>YPbPr, TVP7002+THS8200"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_444_DS_common.inc  // include settings used for all YPbPr input
WR_REG,TVP7000,0x01,0x01,0xA5 // H-PLL Feedback Divider MSBs 2640
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xD8 // H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x32 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x20 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x2C // HSYNC Output Width - 44
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1    HSout+ VSout+
WR_REG,TVP7000,0x01,0x12,0x01 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x00 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0xCF // Input Mux Select 2, SOG LPF bypassed, 4.8MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x39 // HSOUT Output Start (13 + 44)
WR_REG,TVP7000,0x01,0x22,0x00 // MISC Control 4, Macrovision stripper disabled
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x5A // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x03 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x09 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x00 // Video Bandwidth Control (default), maximum B/W selected
//DE
WR_REG,TVP7000,0x01,0x40,0xF9 // AVID Start Pixel LSB  249 (236 + 13) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x79 // AVID Stop Pixel LSB  2169 (AVID Start + 1920) pixels
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x04 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x04 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration  45
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration

//THS8200
INCLUDE,THS8200_HDTV_YCbCr_444_DS_to_YPbPr_common.inc  // include common settings used for all HDTV formats
WR_REG,THS8200,0x01,0x03,0x81 // chip_ctl - high DLL freq range
WR_REG,THS8200,0x01,0x1C,0x78 // data_cntl - D1CLKO disabled, FSADJ1, 4:2:2 to 4:4:4 conversion bypassed,
                              // 1x oversampling, BT.656 output disabled, 30-bit 4:4:4 input format
//timing setup 
WR_REG,THS8200,0x01,0x25,0x2C // dtg1_spec_a
WR_REG,THS8200,0x01,0x26,0x58 // dtg1_spec_b
WR_REG,THS8200,0x01,0x27,0x2C // dtg1_spec_c
WR_REG,THS8200,0x01,0x28,0x84 // dtg1_spec_d
WR_REG,THS8200,0x01,0x29,0x00 // dtg1_spec_d1
WR_REG,THS8200,0x01,0x2A,0xC0 // dtg1_spec_e
WR_REG,THS8200,0x01,0x2B,0x00 // dtg1_spec_h_msb
WR_REG,THS8200,0x01,0x2C,0x00 // dtg1_spec_h_lsb
WR_REG,THS8200,0x01,0x2D,0x00 // dtg1_spec_i_msb
WR_REG,THS8200,0x01,0x2E,0x00 // dtg1_spec_i_lsb
WR_REG,THS8200,0x01,0x2F,0x58 // dtg1_spec_k_lsb
WR_REG,THS8200,0x01,0x30,0x00 // dtg1_spec_k_msb
WR_REG,THS8200,0x01,0x31,0x00 // dtg1_spec_k1
WR_REG,THS8200,0x01,0x32,0x58 // dtg1_spec_g_lsb
WR_REG,THS8200,0x01,0x33,0x00 // dtg1_spec_g_msb
WR_REG,THS8200,0x01,0x34,0x0A // dtg1_total_pixel_msb
WR_REG,THS8200,0x01,0x35,0x50 // dtg1_total_pixel_lsb
WR_REG,THS8200,0x01,0x36,0x80 // dtg1_linecnt_msb
WR_REG,THS8200,0x01,0x37,0x01 // dtg1_linecnt_lsb
WR_REG,THS8200,0x01,0x38,0x80 // dtg1_mode - 1080p
WR_REG,THS8200,0x01,0x39,0x44 // dtg1_frame_field_msb
WR_REG,THS8200,0x01,0x3A,0x65 // dtg1_frame_size_lsb
WR_REG,THS8200,0x01,0x3B,0x65 // dtg1_field_size_lsb

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
